Module interface_impls

Module interface_impls 

Interface Implementations

Interfaces are the “wire format” of ergot. They determine how messages are handled between two devices. Interfaces are typically held by the Profile used by a netstack.

Modules

std_tcp
std tcp interface impl