Interface

Trait Interface 

pub trait Interface {
    type Sink: InterfaceSink;
}
Interfaces define how messages are transported over the wire

Required Associated Types

type Sink: InterfaceSink

The Sink is the type used to send messages out of the Profile

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors