pub trait Interface {
type Sink: InterfaceSink;
}Expand description
Interfaces define how messages are transported over the wire
Required Associated Types
Sourcetype Sink: InterfaceSink
type Sink: InterfaceSink
The Sink is the type used to send messages out of the Profile
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".